.. :changelog:

History
-------

.. to_doc

---------------------
0.4.0 (2022-02-16)
---------------------

* Fix up more arguments to use hyphens instead of underscores.
* Add new command to add labels for all tools from a server (for bootstrapping flavors).
* Readme fixes and improvements.

---------------------
0.3.0 (2021-09-15)
---------------------

* Import and allow export of more data from the initial server requests.

---------------------
0.2.0 (2021-09-15)
---------------------

* Various enhancements - version database, recursive import of metadata, add training metadata to model, etc..

---------------------
0.1.0 (2021-09-13)
---------------------

* Initial version.
